/*
 * Copyright (c) 2004-2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: GraphSchema.java,v 1.22 2007/06/06 15:10:17 sshirasu Exp $
 */

package edu.indiana.extreme.xbaya.graph;

import org.xmlpull.infoset.XmlNamespace;

import edu.indiana.extreme.xbaya.XBayaConstants;
import edu.indiana.extreme.xbaya.util.XMLUtil;

/**
 * @author Satoshi Shirasuna
 */
public class GraphSchema {

    /**
     * Namespace prefix
     */
    public static final String NS_PREFIX_XGR = "xgr";

    /**
     * Namespace URI
     */
    public static final String NS_URI_XGR = XBayaConstants.NS_URI_XBAYA
            + "graph";

    /**
     * Namespace
     */
    public static final XmlNamespace NS = XMLUtil.BUILDER.newNamespace(
            GraphSchema.NS_PREFIX_XGR, GraphSchema.NS_URI_XGR);

    /**
     * The attribute for the version of the XBaya that creates the workflow.
     */
    public static final String XBAYA_VERSION_ATTRIBUTE = "version";

    /**
     * GRAPH_TAG
     */
    public static final String GRAPH_TAG = "graph";

    /**
     * GRAPH_TYPE_ATTRIBUTE
     */
    public static final String GRAPH_TYPE_ATTRIBUTE = "type";

    /**
     * GRAPH_TYPE_WS
     */
    public static final String GRAPH_TYPE_WS = "ws";

    /**
     * The tag for the ID of a graph.
     */
    public static final String GRAPH_ID_TAG = "id";

    /**
     * The tag for the name of a graph.
     */
    public static final String GRAPH_NAME_TAG = "name";

    /**
     * The tag for the description of a graph.
     */
    public static final String GRAPH_DESCRIPTION_TAG = "description";

    /**
     * GRAPH_METADATA_TAG
     */
    public static final String GRAPH_METADATA_TAG = "metadata";

    /**
     * GRAPH_INPUT_METADATA_TAG
     */
    public static final String GRAPH_INPUT_METADATA_TAG = "inputMetadata";

    /**
     * GRAPH_OUTPUT_METADATA_TAG
     */
    public static final String GRAPH_OUTPUT_METADATA_TAG = "outputMetadata";

    // Tags for Node

    /**
     * The tag for a node.
     */
    public static final String NODE_TAG = "node";

    /**
     * type
     */
    public static final String NODE_TYPE_ATTRIBUTE = "type";

    /**
     * ws
     */
    public static final String NODE_TYPE_WS = "ws";

    /**
     * workflow
     */
    public static final String NODE_TYPE_WORKFLOW = "workflow";

    /**
     * Input parameter node
     */
    public static final String NODE_TYPE_INPUT = "input";

    /**
     * Output parameter node
     */
    public static final String NODE_TYPE_OUTPUT = "output";

    /**
     * constant
     */
    public static final String NODE_TYPE_CONSTANT = "constant";

    /**
     * split
     */
    public static final String NODE_TYPE_SPLIT = "split";

    /**
     * merge
     */
    public static final String NODE_TYPE_MERGE = "merge";

    /**
     * if
     */
    public static final String NODE_TYPE_IF = "if";

    /**
     * endif
     */
    public static final String NODE_TYPE_ENDIF = "endif";

    /**
     * block
     */
    public static final String NODE_TYPE_BLOCK = "block";

    /**
     * endBlock
     */
    public static final String NODE_TYPE_ENDBLOCK = "endBlock";

    /**
     * receive
     */
    public static final String NODE_TYPE_RECEIVE = "receive";

    /**
     * Input parameter node
     */
    public static final String NODE_TYPE_MEMO = "memo";

    /**
     * Tag for the ID of a node ID. It is unique among a graph.
     */
    public static final String NODE_ID_TAG = "id";

    /**
     * Tag for the name of a node name. A node name is same as the component
     * name.
     */
    public static final String NODE_NAME_TAG = "name";

    /**
     * Tag for wsdl QName.
     */
    public static final String NODE_WSDL_QNAME_TAG = "wsdl";

    /**
     * portType
     */
    public static final String NODE_WSDL_PORT_TYPE_TAG = "portType";

    /**
     * operationType
     */
    public static final String NODE_WSDL_OPERATION_TAG = "operation";

    /**
     * templateID
     */
    public static final String NODE_TEMPLATE_ID_TAG = "templateID";

    /**
     * Tag for a component (Not used since the introduction of .xwf)
     */
    public static final String NODE_COMPONENT_TAG = "component";

    /**
     * The tag used for the configuration of a node.
     */
    public static final String NODE_CONFIG_TAG = "config";

    /**
     * memo
     */
    public static final String NODE_MEMO_TAG = "memo";

    /**
     * Tag for input port
     */
    public static final String NODE_INPUT_PORT_TAG = "inputPort";

    /**
     * Tag for output port
     */
    public static final String NODE_OUTPUT_PORT_TAG = "outputPort";

    /**
     * controlInPort
     */
    public static final String NODE_CONTROL_IN_PORT_TAG = "controlInPort";

    /**
     * controlOutPort
     */
    public static final String NODE_CONTROL_OUT_PORT_TAG = "controlOutPort";

    /**
     * eprPort
     */
    public static final String NODE_EPR_PORT_TAG = "eprPort";

    /**
     * Tag for x-coordinate
     */
    public static final String NODE_X_LOCATION_TAG = "x";

    /**
     * Tag for y-coordinate
     */
    public static final String NODE_Y_LOCATION_TAG = "y";

    // Tags for Port

    /**
     * The tag for a port.
     */
    public static final String PORT_TAG = "port";

    /**
     * type
     */
    public static final String PORT_TYPE_ATTRIBUTE = "type";

    /**
     * ws
     */
    public static final String PORT_TYPE_WS_DATA = "ws";

    /**
     * dynamicData
     */
    public static final String PORT_TYPE_SYSTEM_DATA = "systemData";

    /**
     * control
     */
    public static final String PORT_TYPE_CONTROL = "control";

    /**
     * epr
     */
    public static final String PORT_TYPE_EPR = "epr";

    /**
     * Tag for the ID of a port
     */
    public static final String PORT_ID_TAG = "id";

    /**
     * Tag for the name of a port
     */
    public static final String PORT_NAME_TAG = "name";

    /**
     * Tag for the data type of a port
     */
    public static final String PORT_DATA_TYPE_TAG = "dataType";

    /**
     * Tag for a node that a port belongs to.
     */
    public static final String PORT_NODE_TAG = "node";

    // Tags for Edge

    /**
     * The tag for an edge
     */
    public static final String EDGE_TAG = "edge";

    /**
     * Tag for the ID of from port of an edge.
     */
    public static final String EDGE_FROM_PORT_TAG = "fromPort";

    /**
     * Tag for the ID of from port of an edge.
     */
    public static final String EDGE_TO_PORT_TAG = "toPort";

    /**
     * type
     */
    public static final String EDGE_TYPE_ATTRIBUTE = "type";

    /**
     * data
     */
    public static final String EDGE_TYPE_DATA = "data";

    /**
     * control
     */
    public static final String EDGE_TYPE_CONTROL = "control";

}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2004-2007 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
